﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Collections;
using ScheduleCRUD.Models;

namespace ScheduleCRUD.Controllers
{
    public class HomeController : Controller
    {
        ScheduleDataDataContext db = new ScheduleDataDataContext();
        public ActionResult Index()
        {
            return View();
        }

        public JsonResult GetData()
        {
            IEnumerable data = new ScheduleDataDataContext().DefaultSchedules.Take(100); // nw.Appointment.Take(5);
            return Json(data, JsonRequestBehavior.AllowGet);
        }
        public JsonResult Batch(EditParams param)
        {
            if (param.action == "insert" || (param.action == "batch" && param.added != null))          // this block of code will execute while inserting the appointments
            {
                var value = param.action == "insert" ? param.value : param.added[0];
                int intMax = db.DefaultSchedules.ToList().Count > 0 ? db.DefaultSchedules.ToList().Max(p => p.Id) : 1;
                DateTime startTime = Convert.ToDateTime(value.StartTime);
                DateTime endTime = Convert.ToDateTime(value.EndTime);
                var currentTimeZone = TimeZone.CurrentTimeZone;
                DefaultSchedule appoint = new DefaultSchedule()
                {
                    Id = value.Id,
                    StartTime = startTime,
                    EndTime = endTime,
                    Subject = value.Subject,
                    Location = value.Location,
                    Description = value.Description,
                    Owner = value.Owner,
                    Priority = value.Priority,
                    Recurrence = value.Recurrence,
                    RecurrenceType = value.RecurrenceType,
                    Reminder = value.Reminder,
                    Categorize = value.Categorize,
                    AllDay = value.AllDay,
                    RecurrenceEndDate = value.RecurrenceEndDate != null ? Convert.ToDateTime(value.RecurrenceEndDate) : endTime,
                    RecurrenceStartDate = value.RecurrenceStartDate != null ? Convert.ToDateTime(value.RecurrenceStartDate) : startTime,
                    RecurrenceRule = value.RecurrenceRule,
                    PatientName=value.PatientName,
                    AppointmentType=value.AppointmentType
                };
                db.DefaultSchedules.InsertOnSubmit(appoint);
                db.SubmitChanges();
            }
            if (param.action == "remove" || param.deleted != null)                                        // this block of code will execute while removing the appointment
            {
                if (param.action == "remove")
                {
                    int key = Convert.ToInt32(param.key);
                    DefaultSchedule app = db.DefaultSchedules.Where(c => c.Id == key).FirstOrDefault();
                    if (app != null) db.DefaultSchedules.DeleteOnSubmit(app);
                }
                else
                {
                    foreach (var apps in param.deleted)
                    {
                        DefaultSchedule app = db.DefaultSchedules.Where(c => c.Id == apps.Id).FirstOrDefault();
                        if (apps != null) db.DefaultSchedules.DeleteOnSubmit(app);
                    }
                }
                db.SubmitChanges();
            }
            if ((param.action == "batch" && param.changed != null) || param.action == "update")   // this block of code will execute while updating the appointment
            {
                var value = param.action == "update" ? param.value : param.changed[0];
                var filterData = db.DefaultSchedules.Where(c => c.Id == Convert.ToInt32(value.Id));

                if (filterData.Count() > 0)
                {
                    DateTime startTime = Convert.ToDateTime(value.StartTime);
                    DateTime endTime = Convert.ToDateTime(value.EndTime);
                    DefaultSchedule appoint = db.DefaultSchedules.Single(A => A.Id == Convert.ToInt32(value.Id));
                    appoint.StartTime = startTime;
                    appoint.EndTime = endTime;
                    appoint.Subject = value.Subject;
                    appoint.Location = value.Location;
                    appoint.Description = value.Description;
                    appoint.Owner = value.Owner;
                    appoint.Priority = Convert.ToByte(value.Priority);
                    appoint.Recurrence = Convert.ToByte(value.Recurrence);
                    appoint.RecurrenceType = value.RecurrenceType;
                    appoint.RecurrenceTypeCount = Convert.ToInt16(value.RecurrenceTypeCount);
                    appoint.Reminder = value.Reminder;
                    appoint.Categorize = value.Categorize;
                    appoint.AllDay = value.AllDay;
                    appoint.RecurrenceEndDate = value.RecurrenceEndDate != null ? Convert.ToDateTime(value.RecurrenceEndDate) : endTime;
                    appoint.RecurrenceStartDate = value.RecurrenceStartDate != null ? Convert.ToDateTime(value.RecurrenceStartDate) : startTime;
                    appoint.RecurrenceRule = value.RecurrenceRule;
                }
                db.SubmitChanges();
            }
            IEnumerable data = new ScheduleDataDataContext().DefaultSchedules.Take(500); // nw.Appointment.Take(5);
            return Json(data, JsonRequestBehavior.AllowGet);
        }
    }
}